@@ -107,7 +107,7 @@ except ImportError:
                           " install ordereddict 1.1 from pypi for python2.6")
 
 __pkgname__ = 'python-crontab'
-__version__ = '2.3.8'
+__version__ = '2.3.9'
 
 ITEMREX = re.compile(r'^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)'
                      r'\s+([^@#\s]+)\s+([^\n]*?)(\s+#\s*([^\n]*)|$)')
@@ -180,11 +180,11 @@ def open_pipe(cmd, *args, **flags):
     env = flags.pop('env', None)
     for (key, value) in flags.items():
         if len(key) == 1:
-            cmd_args += ("-%s" % key),
+            cmd_args += (("-%s" % key),)
             if value is not None:
-                cmd_args += unicode(value),
+                cmd_args += (unicode(value),)
         else:
-            cmd_args += ("--%s=%s" % (key, value)),
+            cmd_args += (("--%s=%s" % (key, value)),)
     args = tuple(arg for arg in (cmd_args + tuple(args)) if arg)
     return sp.Popen(args, stdout=sp.PIPE, stderr=sp.PIPE, env=env)
 
@@ -1085,7 +1085,7 @@ class CronSlice(object):
         if not opts.get('also', False):
             self.clear()
         for set_a in n_value:
-            self.parts += self.parse_value(set_a, sunday=0),
+            self.parts += (self.parse_value(set_a, sunday=0),)
         return self.parts
 
     def during(self, vfrom, vto, also=False):
@@ -1242,7 +1242,7 @@ class CronRange(object):
                     self.dangling = 0
                 self.vto = self.slice.parse_value(vto, sunday=6)
             if self.vto < self.vfrom:
-                LOG.warning("Bad range '{0.vfrom}-{0.vto}'".format(self))
+                raise ValueError("Bad range '{0.vfrom}-{0.vto}'".format(self))
         elif value == '*':
             self.all()
         else:
